NAME = "ESP32_S3_mini"

from machine import Pin

# Left
GPIO18 = A0 = Pin(18)
GPIO17 = A1 = Pin(17)
GPIO16 = A2 = Pin(16)
GPIO15 = A3 = Pin(15)
GPIO14 = A4 = Pin(14)
GPIO8 = A5 = Pin(8)
GPIO36 = SPI_SCK = Pin(36)
GPIO35 = SPI_MOSI = Pin(35)
GPIO37 = SPI_MISO = Pin(37)
GPIO38 = UART_RX = Pin(38)
GPIO39 = UART_TX = Pin(39)

# Right
GPIO13 = D13 = Pin(13)
GPIO12 = D12 = Pin(12)
GPIO11 = D11 = Pin(11)
GPIO10 = D10 = Pin(10)
GPIO9 = D9 = Pin(9)
GPIO6 = D6 = Pin(6)
GPIO5 = D5 = Pin(5)
GPIO4 = I2C_SCL = Pin(4)
GPIO3 = I2C_SDA = Pin(3)

GPIO21 = NEOPIXEL_POWER = Pin(21)
GPIO33 = NEOPIXEL = Pin(33)

# ordered as spiId, sckId, mosiId, misoId
SPI_PORTS = ({"ID": 2, "SPI_SCK": SPI_SCK, "SPI_MOSI": SPI_MOSI, "SPI_MISO": SPI_MISO},)

# ordered as uartId, txId, rxId
UART_PORTS = ({"ID": 0, "UART_TX": UART_TX, "UART_RX": UART_RX},)

# ordered as scl, sda
I2C_PORTS = ({"ID": 0, "I2C_SCL": I2C_SCL, "I2C_SDA": I2C_SDA},)



NAME = "nRF52840"

from machine import Pin

# Left
D0 = A0 = Pin(2)
D1 = A1 = Pin(3)
D2 = A2 = Pin(28)
D3 = A3 = Pin(29)
D4 = A4 = I2C_SDA = Pin(4)
D5 = A5 = I2C_SCL = Pin(5)
D6 = UART_TX = Pin(43)

# Right
D10 = SPI_MOSI = Pin(10)
D9 = SPI_MISO = Pin(9)
D8 = SPI_SCK = Pin(8)
D7 = UART_RX = Pin(44)

# LEDs ~NOT.value()
RED = Pin.board.P26
GREEN = Pin.board.P30
BLUE = Pin.board.P6

# ordered as spiId, sckId, mosiId, misoId
SPI_PORTS = ({"ID": 3, "SPI_SCK": SPI_SCK, "SPI_MOSI": SPI_MOSI, "SPI_MISO": SPI_MISO},)

# ordered as uartId, txId, rxId
UART_PORTS = ({"ID": 0, "UART_TX": UART_TX, "UART_RX": UART_RX},)

# ordered as scl, sda
I2C_PORTS = ({"ID": 0, "I2C_SCL": I2C_SCL, "I2C_SDA": I2C_SDA},)

"""
As you can see in the table, the SPI and the TWI=I2C shares ID's so if you want to use SPI and TWI at the same time you'll need to use SPI0 and TWI1 for example.

If I read the table correctly you have 3 SPI/TWI available so you could use any of the following combinations:
3 SPI / 0 TWI=I2C
2 SPI / 1 TWI=I2C
1 SPI / 2 TWI=I2C
0 SPI / 3 TWI=I2C
"""



NAME = "ESP32_S3_pro"

from machine import Pin

# Left
GPIO35 = D35 = SPI_MOSI = Pin(35)
GPIO37 = D37 = SPI_MISO = Pin(37)
GPIO36 = D36 = SPI_SCK = Pin(36)
GPIO34 = D34 = Pin(34)
GPIO9 = D9 = A8 = I2C_SCL = Pin(9)
GPIO8 = D8 = A7 = I2C_SDA = Pin(8)
GPIO7 = D7 = A6 = Pin(7)
GPIO6 = D6 = A5 = Pin(6)

GPIO43 = D43 = UART_TX = Pin(43)
GPIO44 = D44 = UART_RX = Pin(44)
GPIO38 = D38 = Pin(38)
GPIO39 = D39 = Pin(39)
GPIO40 = D40 = Pin(40)
GPIO41 = D41 = Pin(41)
GPIO42 = D42 = Pin(42)

# Right
RGB_LED_DATA = Pin(18)
DETECT_5V_PRESENT = Pin(33)
BATTERY_VOLTAGE = Pin(10)
LD02_PWR_EN = Pin(17)

GPIO1 = D1 = A0 = Pin(1)
GPIO2 = D2 = A1 = Pin(2)
GPIO3 = D3 = A2 = Pin(3)
GPIO4 = D4 = A3 = Pin(4)
GPIO5 = D4 = A3 = Pin(5)
GPIO21 = D21 = Pin(21)
GPIO0 = D0 = Pin(0)

GPIO16 = D16 = A15 = Pin(16)
GPIO15 = D15 = A14 = Pin(15)
GPIO14 = D14 = A13 = Pin(14)
GPIO13 = D13 = A12 = Pin(13)
GPIO12 = D12 = A11 = Pin(12)

# ordered as spiId, sckId, mosiId, misoId
SPI_PORTS = ({"ID": 1, "SPI_SCK": SPI_SCK, "SPI_MOSI": SPI_MOSI, "SPI_MISO": SPI_MISO},)

# ordered as uartId, txId, rxId
UART_PORTS = ({"ID": 0, "UART_TX": UART_TX, "UART_RX": UART_RX},)

# ordered as scl, sda
I2C_PORTS = ({"ID": 0, "I2C_SCL": I2C_SCL, "I2C_SDA": I2C_SDA},)



# (c) Lukasz Lobocki

import sys

if __name__ == "__main__":
    print(sys.implementation._machine)

if sys.implementation.name == "micropython":
    if sys.implementation._machine == "ESP32C3 module with ESP32C3":
        from .ESP32_C3.pin import *
    elif sys.implementation._machine == "XIAO nRF52840 Sense with NRF52840":
        from .nRF52840.pin import *
    elif sys.implementation._machine == "Raspberry Pi Pico W with RP2040":
        from .RP2040.pin import *
    elif sys.implementation._machine == "ProS3 with ESP32-S3":
        from .ESP32_S3_pro.pin import *
    elif sys.implementation._machine == "ESP32S3 module (spiram) with ESP32S3":
        from .ESP32_S3_mini.pin import *
    else:
        raise NotImplementedError(
            "Unknown board. Implementation: {i}. Machine: {m}.".format(
                i=sys.implementation.name, m=sys.implementation._machine
            )
        )
else:
    raise NotImplementedError(
        "Unknown board. Implementation: {i}. Machine: {m}.".format(
            i=sys.implementation.name, m=sys.implementation._machine
        )
    )



"""Raspberry_Pi_4"""

"""RP Pi 4 pins"""

NAME = "Raspberry_Pi_4"

from machine import Pin

# Left
GPIO2 = Pin(2)
GPIO3 = Pin(3)
GPIO4 = Pin(4)

GPIO17 = Pin(17)
GPIO27 = Pin(27)
GPIO22 = Pin(22)

GPIO10 = Pin(10)
GPIO9 = Pin(9)
GPIO11 = Pin(11)

GPIO0 = Pin(0)
GPIO5 = Pin(5)
GPIO6 = Pin(6)
GPIO13 = Pin(13)
GPIO19 = Pin(19)
GPIO26 = Pin(26)

# Right
GPIO14 = Pin(14)
GPIO15 = Pin(15)
GPIO18 = Pin(18)

GPIO23 = Pin(23)
GPIO24 = Pin(24)

GPIO25 = Pin(25)
GPIO8 = Pin(8)
GPIO7 = Pin(7)
GPIO1 = Pin(1)

GPIO12 = Pin(12)

GPIO16 = Pin(16)
GPIO20 = Pin(20)
GPIO21 = Pin(21)

PWM = (GPIO12, GPIO13, GPIO18, GPIO19)

SPI_PORTS = (
    {
        "ID": 0,
        "SPI_MOSI": GPIO10,
        "SPI_MISO": GPIO9,
        "SPI_SCK": GPIO11,
        "SPI_CE0": GPIO8,
        "SPI_CE1": GPIO7,
    },
    {
        "ID": 1,
        "SPI_MOSI": GPIO20,
        "SPI_MISO": GPIO19,
        "SPI_SCK": GPIO21,
        "SPI_CE0": GPIO18,
        "SPI_CE1": GPIO17,
        "SPI_CE2": GPIO16,
    },
)

UART_PORTS = ({"ID": 0, "UART_TX": GPIO14, "UART_RX": GPIO15},)

I2C_PORTS = (
    {"ID": 0, "I2C_SDA": GPIO2, "I2C_SCL": GPIO3},
    {"ID": 1, "I2C_SDA": GPIO0, "I2C_SCL": GPIO1},
)



NAME = "ESP32_C3"

from machine import Pin

# Left
GPIO2 = D0 = A0 = Pin(2)
GPIO3 = D1 = A1 = Pin(3)
GPIO4 = D2 = A2 = Pin(4)
GPIO5 = D3 = A3 = Pin(5)
GPIO6 = D4 = I2C_SDA = Pin(6)
GPIO7 = D5 = I2C_SCL = Pin(7)
GPIO21 = D6 = UART_TX = Pin(21)

# Right
GPIO10 = D10 = SPI_MOSI = Pin(10)
GPIO9 = D9 = SPI_MISO = Pin(9)
GPIO8 = D8 = SPI_SCK = Pin(8)
GPIO20 = D7 = UART_RX = Pin(20)

# ordered as spiId, sckId, mosiId, misoId
SPI_PORTS = ({"ID": 0, "SPI_SCK": SPI_SCK, "SPI_MOSI": SPI_MOSI, "SPI_MISO": SPI_MISO},)

# ordered as uartId, txId, rxId
UART_PORTS = ({"ID": 0, "UART_TX": UART_TX, "UART_RX": UART_RX},)

# ordered as scl, sda
I2C_PORTS = ({"ID": 0, "I2C_SCL": I2C_SCL, "I2C_SDA": I2C_SDA},)
